==> OB-3.1.2.tar.gz: OB-3.1.2/ob/src/library/Environment.cpp <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#include <OB/Basic.h>
#include <OB/Except.h>
#include <OB/Template.h>
#include <OB/TemplateI.h>
#include <OB/Environment.h>

// ----------------------------------------------------------------------
// External, non-inline duplicate/release for templates
// ----------------------------------------------------------------------

void
OBDuplicate(CORBA_Environment_ptr p)
{
    if(p)
	p -> _OB_incRef();
}

void
OBRelease(CORBA_Environment_ptr p)
{
    if(p)
	p -> _OB_decRef();
}

// ----------------------------------------------------------------------
// Template instantiations
// ----------------------------------------------------------------------

#ifndef HAVE_NO_EXPLICIT_TEMPLATES
template class OBObjVar< CORBA_Environment >;
template class OBObjForSeq< CORBA_Environment >;
template class OBObjSeq< CORBA_Environment >;
template class OBSeqVar< OBObjSeq< CORBA_Environment > >;
#else
#ifdef HAVE_PRAGMA_DEFINE
#pragma define(OBObjVar< CORBA_Environment >)
#pragma define(OBObjForSeq< CORBA_Environment >)
#pragma define(OBObjSeq< CORBA_Environment >)
#pragma define(OBSeqVar< OBObjSeq< CORBA_Environment > >)
#endif
#endif

// ----------------------------------------------------------------------
// Environment constructor and destructor
// ----------------------------------------------------------------------

CORBA_Environment::CORBA_Environment()
    : exception_(0)
{
}

CORBA_Environment::~CORBA_Environment()
{
    delete exception_;
}

// ----------------------------------------------------------------------
// Environment public member implementation
// ----------------------------------------------------------------------

void
CORBA_Environment::exception(CORBA_Exception* p)
{
    delete exception_;
    exception_ = p;
}

CORBA_Exception*
CORBA_Environment::exception() const
{
    return exception_;
}

==> OB-4.0a2.tar.gz: OB-4.0a2/ob/src/library/Environment.cpp <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#include <OB/Basic.h>
#include <OB/Except.h>
#include <OB/Template.h>
#include <OB/TemplateI.h>
#include <OB/OBTypes.h>
#include <OB/Declarations.h>
#include <OB/Environment.h>

using namespace CORBA;
using namespace OB;

// ----------------------------------------------------------------------
// External, non-inline duplicate/release for templates
// ----------------------------------------------------------------------

void
OBDuplicate(CORBA::Environment_ptr p)
{
    if(p)
	p -> _OB_incRef();
}

void
OBRelease(CORBA::Environment_ptr p)
{
    if(p)
	p -> _OB_decRef();
}

// ----------------------------------------------------------------------
// Template instantiations
// ----------------------------------------------------------------------

#ifndef HAVE_NO_EXPLICIT_TEMPLATES
template class OB::ObjVar< Environment >;
template class OB::ObjOut< Environment >;
//template class OB::ObjForSeq< Environment >;
//template class OB::ObjSeq< Environment >;
//template class OB::SeqVar< OB::ObjSeq< Environment > >;
//template class OB::SeqOut< OB::ObjSeq< Environment > >;
#else
#ifdef HAVE_PRAGMA_DEFINE
#pragma define(OB::ObjVar< Environment >)
#pragma define(OB::ObjOut< Environment >)
//#pragma define(OB::ObjForSeq< Environment >)
//#pragma define(OB::ObjSeq< Environment >)
//#pragma define(OB::SeqVar< OB::ObjSeq< Environment > >)
//#pragma define(OB::SeqOut< OB::ObjSeq< Environment > >)
#endif
#endif

// ----------------------------------------------------------------------
// Environment constructor and destructor
// ----------------------------------------------------------------------

Environment::Environment()
    : exception_(0)
{
}

Environment::~Environment()
{
    delete exception_;
}

// ----------------------------------------------------------------------
// Environment public member implementation
// ----------------------------------------------------------------------

void
Environment::exception(Exception* p)
{
    delete exception_;
    exception_ = p;
}

Exception*
Environment::exception() const
{
    return exception_;
}
